package com.hw.wms.service;

import java.util.List;
import com.hw.wms.domain.WmsBaseWarehouse;

/**
 * 仓库Service接口
 *
 * @author xs
 * @date 2023-12-20
 */
public interface IWmsBaseWarehouseService
{
    /**
     * 查询仓库
     *
     * @param warehouseId 仓库主键
     * @return 仓库
     */
    public WmsBaseWarehouse selectWmsBaseWarehouseByWarehouseId(Long warehouseId);

    /**
     * 查询仓库列表
     *
     * @param wmsBaseWarehouse 仓库
     * @return 仓库集合
     */
    public List<WmsBaseWarehouse> selectWmsBaseWarehouseList(WmsBaseWarehouse wmsBaseWarehouse);

    /**
     * 新增仓库
     *
     * @param wmsBaseWarehouse 仓库
     * @return 结果
     */
    public int insertWmsBaseWarehouse(WmsBaseWarehouse wmsBaseWarehouse);

    /**
     * 修改仓库
     *
     * @param wmsBaseWarehouse 仓库
     * @return 结果
     */
    public int updateWmsBaseWarehouse(WmsBaseWarehouse wmsBaseWarehouse);

    /**
     * 批量删除仓库
     *
     * @param warehouseIds 需要删除的仓库主键集合
     * @return 结果
     */
    public int deleteWmsBaseWarehouseByWarehouseIds(Long[] warehouseIds);

    /**
     * 删除仓库信息
     *
     * @param warehouseId 仓库主键
     * @return 结果
     */
    public int deleteWmsBaseWarehouseByWarehouseId(Long warehouseId);


    /**
     * 查询仓库列表Join category
     *
     * @param wmsBaseWarehouse 仓库
     * @return 仓库
     */
    public List<WmsBaseWarehouse> selectWmsBaseWarehouseJoinList(WmsBaseWarehouse wmsBaseWarehouse);
}
